@@ -1,3 +1,3 @@
 from lightning_transformers.core.data import TransformerDataModule  # noqa: F401
 from lightning_transformers.core.finetuning import TransformersBaseFinetuning  # noqa: F401
-from lightning_transformers.core.model import LitTransformer, TaskTransformer  # noqa: F401
+from lightning_transformers.core.model import TaskTransformer  # noqa: F401
